@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2013-2015 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2013-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -27,23 +27,26 @@
 */
 
 #include "probecontroller.h"
+
 #include "probe.h"
 
+#include <QDebug>
 #include <QCoreApplication>
+#include <QMutexLocker>
 
 using namespace GammaRay;
 
-ProbeController::ProbeController(QObject* parent): QObject(parent)
+ProbeController::ProbeController(QObject *parent)
+    : ProbeControllerInterface(parent)
 {
 }
 
 void ProbeController::detachProbe()
 {
-  Probe::instance()->deleteLater();
+    Probe::instance()->deleteLater();
 }
 
 void ProbeController::quitHost()
 {
-  QCoreApplication::instance()->quit();
+    QCoreApplication::instance()->quit();
 }
-
