@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2012-2015 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2012-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -32,13 +32,12 @@
 using namespace GammaRay;
 
 StandardPaths::StandardPaths(ProbeInterface *probe, QObject *parent)
-  : QObject(parent)
+    : QObject(parent)
 {
-  StandardPathsModel *model = new StandardPathsModel(this);
-  probe->registerModel("com.kdab.GammaRay.StandardPathsModel", model);
+    auto *model = new StandardPathsModel(this);
+    probe->registerModel(QStringLiteral("com.kdab.GammaRay.StandardPathsModel"), model);
 }
 
 StandardPaths::~StandardPaths()
 {
 }
-
