@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2013-2015 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2013-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Milian Wolff <milian.wolff@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -32,18 +32,14 @@
 #include <QObject>
 
 namespace GammaRay {
-
 class BenchSuite : public QObject
 {
-  Q_OBJECT
+    Q_OBJECT
 
-  private slots:
+private slots:
     void iconForObject();
-    void connectionModel_connectionAdded();
-    void connectionModel_connectionRemoved();
     void probe_objectAdded();
 };
-
 }
 
 #endif // GAMMARAY_BENCHSUITE_H
