@@ -2,7 +2,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2013-2015 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2013-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -27,12 +27,12 @@
 #include <QGuiApplication>
 #include <QQuickView>
 
-int main(int argc, char** argv)
+int main(int argc, char **argv)
 {
     QGuiApplication app(argc, argv);
 
     QQuickView view;
-    view.setSource(QUrl("qrc:/wk2application.qml"));
+    view.setSource(QUrl(QStringLiteral("qrc:/wk2application.qml")));
     view.show();
 
     return app.exec();
